# This file is auto-generated by the Perl DateTime Suite VTIMEZONE
# parser (0.07).
#
# Do not edit this file directly.

package DateTime::TimeZone;

use strict;

@DateTime::TimeZone::ALL =
qw(
  Africa/Abidjan
  Africa/Accra
  Africa/Addis_Ababa
  Africa/Algiers
  Africa/Asmera
  Africa/Bamako
  Africa/Bangui
  Africa/Banjul
  Africa/Bissau
  Africa/Blantyre
  Africa/Brazzaville
  Africa/Bujumbura
  Africa/Cairo
  Africa/Casablanca
  Africa/Ceuta
  Africa/Conakry
  Africa/Dakar
  Africa/Dar_es_Salaam
  Africa/Djibouti
  Africa/Douala
  Africa/El_Aaiun
  Africa/Freetown
  Africa/Gaborone
  Africa/Harare
  Africa/Johannesburg
  Africa/Kampala
  Africa/Khartoum
  Africa/Kigali
  Africa/Kinshasa
  Africa/Lagos
  Africa/Libreville
  Africa/Lome
  Africa/Luanda
  Africa/Lubumbashi
  Africa/Lusaka
  Africa/Malabo
  Africa/Maputo
  Africa/Maseru
  Africa/Mbabane
  Africa/Mogadishu
  Africa/Monrovia
  Africa/Nairobi
  Africa/Ndjamena
  Africa/Niamey
  Africa/Nouakchott
  Africa/Ouagadougou
  Africa/Porto-Novo
  Africa/Sao_Tome
  Africa/Timbuktu
  Africa/Tripoli
  Africa/Tunis
  Africa/Windhoek
  America/Adak
  America/Anchorage
  America/Anguilla
  America/Antigua
  America/Araguaina
  America/Aruba
  America/Asuncion
  America/Bahia
  America/Barbados
  America/Belem
  America/Belize
  America/Boa_Vista
  America/Bogota
  America/Boise
  America/Buenos_Aires
  America/Cambridge_Bay
  America/Campo_Grande
  America/Cancun
  America/Caracas
  America/Catamarca
  America/Cayenne
  America/Cayman
  America/Chicago
  America/Chihuahua
  America/Cordoba
  America/Costa_Rica
  America/Cuiaba
  America/Curacao
  America/Danmarkshavn
  America/Dawson
  America/Dawson_Creek
  America/Denver
  America/Detroit
  America/Dominica
  America/Edmonton
  America/Eirunepe
  America/El_Salvador
  America/Fortaleza
  America/Glace_Bay
  America/Godthab
  America/Goose_Bay
  America/Grand_Turk
  America/Grenada
  America/Guadeloupe
  America/Guatemala
  America/Guayaquil
  America/Guyana
  America/Halifax
  America/Havana
  America/Hermosillo
  America/Indiana/Knox
  America/Indiana/Marengo
  America/Indiana/Vevay
  America/Indianapolis
  America/Inuvik
  America/Iqaluit
  America/Jamaica
  America/Jujuy
  America/Juneau
  America/Kentucky/Monticello
  America/La_Paz
  America/Lima
  America/Los_Angeles
  America/Louisville
  America/Maceio
  America/Managua
  America/Manaus
  America/Martinique
  America/Mazatlan
  America/Mendoza
  America/Menominee
  America/Merida
  America/Mexico_City
  America/Miquelon
  America/Monterrey
  America/Montevideo
  America/Montreal
  America/Montserrat
  America/Nassau
  America/New_York
  America/Nipigon
  America/Nome
  America/Noronha
  America/North_Dakota/Center
  America/Panama
  America/Pangnirtung
  America/Paramaribo
  America/Phoenix
  America/Port-au-Prince
  America/Port_of_Spain
  America/Porto_Velho
  America/Puerto_Rico
  America/Rainy_River
  America/Rankin_Inlet
  America/Recife
  America/Regina
  America/Rio_Branco
  America/Santiago
  America/Santo_Domingo
  America/Sao_Paulo
  America/Scoresbysund
  America/St_Johns
  America/St_Kitts
  America/St_Lucia
  America/St_Thomas
  America/St_Vincent
  America/Swift_Current
  America/Tegucigalpa
  America/Thule
  America/Thunder_Bay
  America/Tijuana
  America/Toronto
  America/Tortola
  America/Vancouver
  America/Whitehorse
  America/Winnipeg
  America/Yakutat
  America/Yellowknife
  Antarctica/Casey
  Antarctica/Davis
  Antarctica/DumontDUrville
  Antarctica/Mawson
  Antarctica/McMurdo
  Antarctica/Palmer
  Antarctica/Rothera
  Antarctica/Syowa
  Antarctica/Vostok
  Asia/Aden
  Asia/Almaty
  Asia/Amman
  Asia/Anadyr
  Asia/Aqtau
  Asia/Aqtobe
  Asia/Ashgabat
  Asia/Baghdad
  Asia/Bahrain
  Asia/Baku
  Asia/Bangkok
  Asia/Beirut
  Asia/Bishkek
  Asia/Brunei
  Asia/Calcutta
  Asia/Choibalsan
  Asia/Chongqing
  Asia/Colombo
  Asia/Damascus
  Asia/Dhaka
  Asia/Dili
  Asia/Dubai
  Asia/Dushanbe
  Asia/Gaza
  Asia/Harbin
  Asia/Hong_Kong
  Asia/Hovd
  Asia/Irkutsk
  Asia/Jakarta
  Asia/Jayapura
  Asia/Jerusalem
  Asia/Kabul
  Asia/Kamchatka
  Asia/Karachi
  Asia/Kashgar
  Asia/Katmandu
  Asia/Krasnoyarsk
  Asia/Kuala_Lumpur
  Asia/Kuching
  Asia/Kuwait
  Asia/Macau
  Asia/Magadan
  Asia/Makassar
  Asia/Manila
  Asia/Muscat
  Asia/Nicosia
  Asia/Novosibirsk
  Asia/Omsk
  Asia/Oral
  Asia/Phnom_Penh
  Asia/Pontianak
  Asia/Pyongyang
  Asia/Qatar
  Asia/Qyzylorda
  Asia/Rangoon
  Asia/Riyadh
  Asia/Saigon
  Asia/Sakhalin
  Asia/Samarkand
  Asia/Seoul
  Asia/Shanghai
  Asia/Singapore
  Asia/Taipei
  Asia/Tashkent
  Asia/Tbilisi
  Asia/Tehran
  Asia/Thimphu
  Asia/Tokyo
  Asia/Ulaanbaatar
  Asia/Urumqi
  Asia/Vientiane
  Asia/Vladivostok
  Asia/Yakutsk
  Asia/Yekaterinburg
  Asia/Yerevan
  Atlantic/Azores
  Atlantic/Bermuda
  Atlantic/Canary
  Atlantic/Cape_Verde
  Atlantic/Faeroe
  Atlantic/Madeira
  Atlantic/Reykjavik
  Atlantic/South_Georgia
  Atlantic/St_Helena
  Atlantic/Stanley
  Australia/Adelaide
  Australia/Brisbane
  Australia/Broken_Hill
  Australia/Darwin
  Australia/Hobart
  Australia/Lindeman
  Australia/Lord_Howe
  Australia/Melbourne
  Australia/Perth
  Australia/Sydney
  Europe/Amsterdam
  Europe/Andorra
  Europe/Athens
  Europe/Belfast
  Europe/Belgrade
  Europe/Berlin
  Europe/Brussels
  Europe/Bucharest
  Europe/Budapest
  Europe/Chisinau
  Europe/Copenhagen
  Europe/Dublin
  Europe/Gibraltar
  Europe/Helsinki
  Europe/Istanbul
  Europe/Kaliningrad
  Europe/Kiev
  Europe/Lisbon
  Europe/London
  Europe/Luxembourg
  Europe/Madrid
  Europe/Malta
  Europe/Minsk
  Europe/Monaco
  Europe/Moscow
  Europe/Oslo
  Europe/Paris
  Europe/Prague
  Europe/Riga
  Europe/Rome
  Europe/Samara
  Europe/Simferopol
  Europe/Sofia
  Europe/Stockholm
  Europe/Tallinn
  Europe/Tirane
  Europe/Uzhgorod
  Europe/Vaduz
  Europe/Vienna
  Europe/Vilnius
  Europe/Warsaw
  Europe/Zaporozhye
  Europe/Zurich
  Indian/Antananarivo
  Indian/Chagos
  Indian/Christmas
  Indian/Cocos
  Indian/Comoro
  Indian/Kerguelen
  Indian/Mahe
  Indian/Maldives
  Indian/Mauritius
  Indian/Mayotte
  Indian/Reunion
  Pacific/Apia
  Pacific/Auckland
  Pacific/Chatham
  Pacific/Easter
  Pacific/Efate
  Pacific/Enderbury
  Pacific/Fakaofo
  Pacific/Fiji
  Pacific/Funafuti
  Pacific/Galapagos
  Pacific/Gambier
  Pacific/Guadalcanal
  Pacific/Guam
  Pacific/Honolulu
  Pacific/Johnston
  Pacific/Kiritimati
  Pacific/Kosrae
  Pacific/Kwajalein
  Pacific/Majuro
  Pacific/Marquesas
  Pacific/Midway
  Pacific/Nauru
  Pacific/Niue
  Pacific/Norfolk
  Pacific/Noumea
  Pacific/Pago_Pago
  Pacific/Palau
  Pacific/Pitcairn
  Pacific/Ponape
  Pacific/Port_Moresby
  Pacific/Rarotonga
  Pacific/Saipan
  Pacific/Tahiti
  Pacific/Tarawa
  Pacific/Tongatapu
  Pacific/Truk
  Pacific/Wake
  Pacific/Wallis
  Pacific/Yap
);

@DateTime::TimeZone::CATEGORY_NAMES =
qw(
  Africa
  America
  Antarctica
  Asia
  Atlantic
  Australia
  Europe
  Indian
  Pacific
);

%DateTime::TimeZone::CATEGORIES =
(
'Africa' => [ qw(
  Abidjan
  Accra
  Addis_Ababa
  Algiers
  Asmera
  Bamako
  Bangui
  Banjul
  Bissau
  Blantyre
  Brazzaville
  Bujumbura
  Cairo
  Casablanca
  Ceuta
  Conakry
  Dakar
  Dar_es_Salaam
  Djibouti
  Douala
  El_Aaiun
  Freetown
  Gaborone
  Harare
  Johannesburg
  Kampala
  Khartoum
  Kigali
  Kinshasa
  Lagos
  Libreville
  Lome
  Luanda
  Lubumbashi
  Lusaka
  Malabo
  Maputo
  Maseru
  Mbabane
  Mogadishu
  Monrovia
  Nairobi
  Ndjamena
  Niamey
  Nouakchott
  Ouagadougou
  Porto-Novo
  Sao_Tome
  Timbuktu
  Tripoli
  Tunis
  Windhoek
) ],
'America' => [ qw(
  Adak
  Anchorage
  Anguilla
  Antigua
  Araguaina
  Aruba
  Asuncion
  Bahia
  Barbados
  Belem
  Belize
  Boa_Vista
  Bogota
  Boise
  Buenos_Aires
  Cambridge_Bay
  Campo_Grande
  Cancun
  Caracas
  Catamarca
  Cayenne
  Cayman
  Chicago
  Chihuahua
  Cordoba
  Costa_Rica
  Cuiaba
  Curacao
  Danmarkshavn
  Dawson
  Dawson_Creek
  Denver
  Detroit
  Dominica
  Edmonton
  Eirunepe
  El_Salvador
  Fortaleza
  Glace_Bay
  Godthab
  Goose_Bay
  Grand_Turk
  Grenada
  Guadeloupe
  Guatemala
  Guayaquil
  Guyana
  Halifax
  Havana
  Hermosillo
  Indiana/Knox
  Indiana/Marengo
  Indiana/Vevay
  Indianapolis
  Inuvik
  Iqaluit
  Jamaica
  Jujuy
  Juneau
  Kentucky/Monticello
  La_Paz
  Lima
  Los_Angeles
  Louisville
  Maceio
  Managua
  Manaus
  Martinique
  Mazatlan
  Mendoza
  Menominee
  Merida
  Mexico_City
  Miquelon
  Monterrey
  Montevideo
  Montreal
  Montserrat
  Nassau
  New_York
  Nipigon
  Nome
  Noronha
  North_Dakota/Center
  Panama
  Pangnirtung
  Paramaribo
  Phoenix
  Port-au-Prince
  Port_of_Spain
  Porto_Velho
  Puerto_Rico
  Rainy_River
  Rankin_Inlet
  Recife
  Regina
  Rio_Branco
  Santiago
  Santo_Domingo
  Sao_Paulo
  Scoresbysund
  St_Johns
  St_Kitts
  St_Lucia
  St_Thomas
  St_Vincent
  Swift_Current
  Tegucigalpa
  Thule
  Thunder_Bay
  Tijuana
  Toronto
  Tortola
  Vancouver
  Whitehorse
  Winnipeg
  Yakutat
  Yellowknife
) ],
'Antarctica' => [ qw(
  Casey
  Davis
  DumontDUrville
  Mawson
  McMurdo
  Palmer
  Rothera
  Syowa
  Vostok
) ],
'Asia' => [ qw(
  Aden
  Almaty
  Amman
  Anadyr
  Aqtau
  Aqtobe
  Ashgabat
  Baghdad
  Bahrain
  Baku
  Bangkok
  Beirut
  Bishkek
  Brunei
  Calcutta
  Choibalsan
  Chongqing
  Colombo
  Damascus
  Dhaka
  Dili
  Dubai
  Dushanbe
  Gaza
  Harbin
  Hong_Kong
  Hovd
  Irkutsk
  Jakarta
  Jayapura
  Jerusalem
  Kabul
  Kamchatka
  Karachi
  Kashgar
  Katmandu
  Krasnoyarsk
  Kuala_Lumpur
  Kuching
  Kuwait
  Macau
  Magadan
  Makassar
  Manila
  Muscat
  Nicosia
  Novosibirsk
  Omsk
  Oral
  Phnom_Penh
  Pontianak
  Pyongyang
  Qatar
  Qyzylorda
  Rangoon
  Riyadh
  Saigon
  Sakhalin
  Samarkand
  Seoul
  Shanghai
  Singapore
  Taipei
  Tashkent
  Tbilisi
  Tehran
  Thimphu
  Tokyo
  Ulaanbaatar
  Urumqi
  Vientiane
  Vladivostok
  Yakutsk
  Yekaterinburg
  Yerevan
) ],
'Atlantic' => [ qw(
  Azores
  Bermuda
  Canary
  Cape_Verde
  Faeroe
  Madeira
  Reykjavik
  South_Georgia
  St_Helena
  Stanley
) ],
'Australia' => [ qw(
  Adelaide
  Brisbane
  Broken_Hill
  Darwin
  Hobart
  Lindeman
  Lord_Howe
  Melbourne
  Perth
  Sydney
) ],
'Europe' => [ qw(
  Amsterdam
  Andorra
  Athens
  Belfast
  Belgrade
  Berlin
  Brussels
  Bucharest
  Budapest
  Chisinau
  Copenhagen
  Dublin
  Gibraltar
  Helsinki
  Istanbul
  Kaliningrad
  Kiev
  Lisbon
  London
  Luxembourg
  Madrid
  Malta
  Minsk
  Monaco
  Moscow
  Oslo
  Paris
  Prague
  Riga
  Rome
  Samara
  Simferopol
  Sofia
  Stockholm
  Tallinn
  Tirane
  Uzhgorod
  Vaduz
  Vienna
  Vilnius
  Warsaw
  Zaporozhye
  Zurich
) ],
'Indian' => [ qw(
  Antananarivo
  Chagos
  Christmas
  Cocos
  Comoro
  Kerguelen
  Mahe
  Maldives
  Mauritius
  Mayotte
  Reunion
) ],
'Pacific' => [ qw(
  Apia
  Auckland
  Chatham
  Easter
  Efate
  Enderbury
  Fakaofo
  Fiji
  Funafuti
  Galapagos
  Gambier
  Guadalcanal
  Guam
  Honolulu
  Johnston
  Kiritimati
  Kosrae
  Kwajalein
  Majuro
  Marquesas
  Midway
  Nauru
  Niue
  Norfolk
  Noumea
  Pago_Pago
  Palau
  Pitcairn
  Ponape
  Port_Moresby
  Rarotonga
  Saipan
  Tahiti
  Tarawa
  Tongatapu
  Truk
  Wake
  Wallis
  Yap
) ],

);

%DateTime::TimeZone::LINKS =
(
  'America/Atka' => 'America/Adak',
  'America/Ensenada' => 'America/Tijuana',
  'America/Fort_Wayne' => 'America/Indianapolis',
  'America/Indiana/Indianapolis' => 'America/Indianapolis',
  'America/Kentucky/Louisville' => 'America/Louisville',
  'America/Knox_IN' => 'America/Indiana/Knox',
  'America/Porto_Acre' => 'America/Rio_Branco',
  'America/Rosario' => 'America/Cordoba',
  'America/Shiprock' => 'America/Denver',
  'America/Virgin' => 'America/St_Thomas',
  'Antarctica/South_Pole' => 'Antarctica/McMurdo',
  'Arctic/Longyearbyen' => 'Europe/Oslo',
  'Asia/Ashkhabad' => 'Asia/Ashgabat',
  'Asia/Chungking' => 'Asia/Chongqing',
  'Asia/Dacca' => 'Asia/Dhaka',
  'Asia/Istanbul' => 'Europe/Istanbul',
  'Asia/Macao' => 'Asia/Macau',
  'Asia/Tel_Aviv' => 'Asia/Jerusalem',
  'Asia/Thimbu' => 'Asia/Thimphu',
  'Asia/Ujung_Pandang' => 'Asia/Makassar',
  'Asia/Ulan_Bator' => 'Asia/Ulaanbaatar',
  'Atlantic/Jan_Mayen' => 'Europe/Oslo',
  'Australia/ACT' => 'Australia/Sydney',
  'Australia/Canberra' => 'Australia/Sydney',
  'Australia/LHI' => 'Australia/Lord_Howe',
  'Australia/NSW' => 'Australia/Sydney',
  'Australia/North' => 'Australia/Darwin',
  'Australia/Queensland' => 'Australia/Brisbane',
  'Australia/South' => 'Australia/Adelaide',
  'Australia/Tasmania' => 'Australia/Hobart',
  'Australia/Victoria' => 'Australia/Melbourne',
  'Australia/West' => 'Australia/Perth',
  'Australia/Yancowinna' => 'Australia/Broken_Hill',
  'Brazil/Acre' => 'America/Porto_Acre',
  'Brazil/DeNoronha' => 'America/Noronha',
  'Brazil/East' => 'America/Sao_Paulo',
  'Brazil/West' => 'America/Manaus',
  'CST6CDT' => 'America/Chicago',
  'Canada/Atlantic' => 'America/Halifax',
  'Canada/Central' => 'America/Winnipeg',
  'Canada/East-Saskatchewan' => 'America/Regina',
  'Canada/Eastern' => 'America/Toronto',
  'Canada/Mountain' => 'America/Edmonton',
  'Canada/Newfoundland' => 'America/St_Johns',
  'Canada/Pacific' => 'America/Vancouver',
  'Canada/Saskatchewan' => 'America/Regina',
  'Canada/Yukon' => 'America/Whitehorse',
  'Chile/Continental' => 'America/Santiago',
  'Chile/EasterIsland' => 'Pacific/Easter',
  'Cuba' => 'America/Havana',
  'EST5EDT' => 'America/New_York',
  'Egypt' => 'Africa/Cairo',
  'Eire' => 'Europe/Dublin',
  'Etc/GMT+0' => 'UTC',
  'Etc/UCT' => 'UTC',
  'Etc/Universal' => 'UTC',
  'Etc/Zulu' => 'UTC',
  'Europe/Bratislava' => 'Europe/Prague',
  'Europe/Ljubljana' => 'Europe/Belgrade',
  'Europe/Nicosia' => 'Asia/Nicosia',
  'Europe/San_Marino' => 'Europe/Rome',
  'Europe/Sarajevo' => 'Europe/Belgrade',
  'Europe/Skopje' => 'Europe/Belgrade',
  'Europe/Tiraspol' => 'Europe/Chisinau',
  'Europe/Vatican' => 'Europe/Rome',
  'Europe/Zagreb' => 'Europe/Belgrade',
  'GB' => 'Europe/London',
  'GB-Eire' => 'Europe/London',
  'GMT' => 'UTC',
  'GMT+0' => 'Etc/GMT+0',
  'GMT-0' => 'Etc/GMT-0',
  'GMT0' => 'UTC',
  'Greenwich' => 'Etc/Greenwich',
  'HST' => 'Pacific/Honolulu',
  'Hongkong' => 'Asia/Hong_Kong',
  'Iceland' => 'Atlantic/Reykjavik',
  'Iran' => 'Asia/Tehran',
  'Israel' => 'Asia/Jerusalem',
  'Jamaica' => 'America/Jamaica',
  'Japan' => 'Asia/Tokyo',
  'Kwajalein' => 'Pacific/Kwajalein',
  'Libya' => 'Africa/Tripoli',
  'MST7MDT' => 'America/Denver',
  'Mexico/BajaNorte' => 'America/Tijuana',
  'Mexico/BajaSur' => 'America/Mazatlan',
  'Mexico/General' => 'America/Mexico_City',
  'NZ' => 'Pacific/Auckland',
  'NZ-CHAT' => 'Pacific/Chatham',
  'Navajo' => 'America/Denver',
  'PRC' => 'Asia/Shanghai',
  'PST8PDT' => 'America/Los_Angeles',
  'Pacific/Samoa' => 'Pacific/Pago_Pago',
  'Poland' => 'Europe/Warsaw',
  'Portugal' => 'Europe/Lisbon',
  'ROC' => 'Asia/Taipei',
  'ROK' => 'Asia/Seoul',
  'Singapore' => 'Asia/Singapore',
  'Turkey' => 'Europe/Istanbul',
  'UCT' => 'Etc/UCT',
  'US/Alaska' => 'America/Anchorage',
  'US/Aleutian' => 'America/Adak',
  'US/Arizona' => 'America/Phoenix',
  'US/Central' => 'America/Chicago',
  'US/East-Indiana' => 'America/Indianapolis',
  'US/Eastern' => 'America/New_York',
  'US/Hawaii' => 'Pacific/Honolulu',
  'US/Indiana-Starke' => 'America/Indiana/Knox',
  'US/Michigan' => 'America/Detroit',
  'US/Mountain' => 'America/Denver',
  'US/Pacific' => 'America/Los_Angeles',
  'US/Pacific-New' => 'America/Los_Angeles',
  'US/Samoa' => 'Pacific/Pago_Pago',
  'Universal' => 'Etc/Universal',
  'W-SU' => 'Europe/Moscow',
  'Zulu' => 'Etc/Zulu'
)

;

sub all_names { wantarray ? @DateTime::TimeZone::ALL : \@DateTime::TimeZone::ALL }
sub categories { wantarray ? @DateTime::TimeZone::CATEGORY_NAMES : \@DateTime::TimeZone::CATEGORY_NAMES }
sub links { wantarray ? %DateTime::TimeZone::LINKS : \%DateTime::TimeZone::LINKS }

sub names_in_category
{
    return unless exists $DateTime::TimeZone::CATEGORIES{ $_[0] };

    return wantarray ? @{ $DateTime::TimeZone::CATEGORIES{ $_[0] } } : $DateTime::TimeZone::CATEGORIES{ $_[0] };
}

1;

__END__

=head1 NAME

DateTime::TimeZoneCatalog - Provides a list of all valid time zone names

=head1 SYNOPSIS

See DateTime::TimeZone for usage details.

=head1 DESCRIPTION

This module contains an enumerated list of all known system timezones,
so that applications can easily present a list of timezones.

=cut

